@@ -6,7 +6,7 @@ package Dist::Zilla::Plugin::Author::CSSON::GithubActions;
 
 # ABSTRACT: Ease creation of common Github Actions workflows
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.0101';
+our $VERSION = '0.0102';
 
 use Moose;
 use namespace::autoclean;
@@ -21,6 +21,7 @@ use Dist::Zilla::File::InMemory;
 with qw/
     Dist::Zilla::Role::Plugin
     Dist::Zilla::Role::FileGatherer
+    Dist::Zilla::Role::FilePruner
 /;
 
 sub mvp_multivalue_args {
@@ -146,6 +147,16 @@ sub gather_files {
 
 }
 
+sub prune_files {
+    my $self = shift;
+    $self->log(['Pruning...']);
+
+    my $yaml = $self->_prepare_yaml;
+    my $file = first { $_->name eq $self->filepath($yaml) } @{ $self->zilla->files };
+
+    $self->zilla->prune_file($file) if $file;
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -166,16 +177,16 @@ Dist::Zilla::Plugin::Author::CSSON::GithubActions - Ease creation of common Gith
 
 <p>
 <img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
-<a href="http://cpants.cpanauthors.org/release/CSSON/Dist-Zilla-Plugin-Author-CSSON-GithubActions-0.0101"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/Dist-Zilla-Plugin-Author-CSSON-GithubActions/0.0101" alt="Distribution kwalitee" /></a>
-<a href="http://matrix.cpantesters.org/?dist=Dist-Zilla-Plugin-Author-CSSON-GithubActions%200.0101"><img src="http://badgedepot.code301.com/badge/cpantesters/Dist-Zilla-Plugin-Author-CSSON-GithubActions/0.0101" alt="CPAN Testers result" /></a>
-<img src="https://img.shields.io/badge/coverage-92.3%-yellow.svg" alt="coverage 92.3%" />
+<a href="http://cpants.cpanauthors.org/release/CSSON/Dist-Zilla-Plugin-Author-CSSON-GithubActions-0.0102"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/Dist-Zilla-Plugin-Author-CSSON-GithubActions/0.0102" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Dist-Zilla-Plugin-Author-CSSON-GithubActions%200.0102"><img src="http://badgedepot.code301.com/badge/cpantesters/Dist-Zilla-Plugin-Author-CSSON-GithubActions/0.0102" alt="CPAN Testers result" /></a>
+<img src="https://img.shields.io/badge/coverage-91.7%-yellow.svg" alt="coverage 91.7%" />
 </p>
 
 =end html
 
 =head1 VERSION
 
-Version 0.0101, released 2020-12-25.
+Version 0.0102, released 2020-12-25.
 
 =head1 SYNOPSIS
 
